![logo](https://mk0dataloop4fni44fjg.kinstacdn.com/wp-content/uploads/2020/03/logo.svg)

This is the SDK and CLI open source repository for [Dataloop.ai](https://dataloop.ai/) platform

For full platform documentation click [here](https://docs.dataloop.ai/docs)

For full SDK documentation click [here](https://console.dataloop.ai/sdk-docs/latest)
